colormap

package
v0.0.0-...-21bf895 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 24, 2021 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Get

func Get(key string) string

Get returns a color from the colormap

func Load

func Load(path string)

Load loads the colormap based on the configuration files needs to be called first to initialize the colormap

Types

This section is empty.

Jump to